---
title: <span class="badge object-type-scalar"></span> EventsPerSecond
---
# <span class="badge object-type-scalar"></span> EventsPerSecond

Throughput: events/sec (eps)

## Definition

```python
# Throughput: events/sec (eps)
EventsPerSecond: typing.Literal["eps"] = "eps"
```
